@@ -450,3 +450,30 @@ ATTR_RC_MACRO_DISCUSSION = u"Macro ds name"
 ATTR_AUTH_TOKEN = u"Auth token"
 ATTR_USER_NAME = u"username"
 ATTR_PASSWORD = u"Password"
+
+ATTR_ANALOGUE_PROGRAMMING_ACTIVE = u"Analogue prog. active"
+ATTR_CALIBRATION_MODE = u"Calibration mode"
+ATTR_CONTROL_CURRENT = u"Control current"
+ATTR_CONTROL_VOLTAGE = u"Control voltage"
+ATTR_CURRENT_RAMPING_RATE = u"Current ramping rate"
+ATTR_DIGITAL_PROGRAMMING_ACTIVE = u"Digital prog. active"
+ATTR_MONITORED_CURRENT = u"I-Mon"
+ATTR_MONITORED_VOLTAGE = u"V-Mon"
+ATTR_OUTPUT_POLARITY = u"Output polarity"
+ATTR_OUTPUT_RELEASE = u"Output release"
+ATTR_POLARITY_REVERSAL = u"Polarity"
+ATTR_VOLTAGE_RAMPING_RATE = u"Voltage ramping rate"
+ATTR_VOLTAGE_READOUT = u"Voltage readout"
+ATTR_CURRENT_READOUT = u"Current readout"
+ATTR_CURRENT_ON_TARGET = u"Current on target"
+ATTR_VOLTAGE_ON_TARGET = u"Voltage on target"
+ATTR_RAMP_VOLTAGE_MODE = u"Ramp voltage mode"
+ATTR_RAMP_CURRENT_MODE = u"Ramp current mode"
+ATTR_OUTPUT_POWER = u"Output power"
+ATTR_DIGITAL_OUTPUT = "Digital output"
+ATTR_DIGITAL_INPUT = "Digital input"
+ATTR_ANALOG_OUTPUT = "Analog output"
+ATTR_ANALOG_INPUT = "Analog input"
+ATTR_CHANNELS_CONFIGURATION = "Channels configuration"
+ATTR_NAME = "Name"
+ATTR_MEASUREMENT_STATUS = "Measurement status"
