@@ -190,6 +190,11 @@ class Device(Subject, YamlSerializable):
         if attribute_exists and kamzik3.session.publisher is not None:
             header = "{}.{}".format(attribute.attribute_id, TOKEN_ATTRIBUTE_REPLACE)
             kamzik3.session.publisher.push_message(header, attribute)
+        if attribute.attribute_id is None:
+            attribute_path = name
+            if group is not None:
+                attribute_path = "{}.{}".format(group, attribute_path)
+            attribute.attribute_id = "{}.{}.{}".format(self.device_id, TOKEN_ATTRIBUTE, attribute_path)
         return attribute
 
     def delete_attribute(self, name, group=None):
