@@ -394,35 +394,6 @@ class DeviceClient(Device):
         current_value = get_from_dict(self.attributes, attribute)
         if not is_equal(value, current_value):
             set_in_dict(self.attributes, attribute, value)
-        # try:
-        #     if value != current_value:
-        #         set_in_dict(self.attributes, attribute, value)
-        # except ValueError:
-        #     if not np.array_equal(value, current_value):
-        #         set_in_dict(self.attributes, attribute, value)
-
-    def poll(self):
-        """
-        Poll devices for activity.
-        :return:
-        """
-        if not self.connected and not self.connecting or not self.socket:
-            raise DeviceClientError(
-                u"Remote server poll failed. Device client is not connected")
-        try:
-            with self.client_comm_lock:
-                self.socket.send_multipart([INSTRUCTION_POLL, self.device_id.encode()])
-                status, token, response = self.handle_server_response()
-            if status == RESPONSE_OK:
-                return response
-            else:
-                raise DeviceClientError(u"Failed to poll remote device")
-
-        except zmq.Again:
-            return False
-        except zmq.ZMQError as e:
-            self.handle_response_error(u"Poll error: {}".format(e))
-            return False
 
     def command(self, command, callback=None):
         """
