@@ -408,7 +408,9 @@ class DeviceLexiumChannel(DeviceChannel):
             else:
                 position = int(round((position / 360.) * (
                         self.get_value(ATTR_MICROSTEP_RESOLUTION) * self.get_value(ATTR_STEPS_PER_REVOLUTION))))
-            return self.command(u"MA {}\r".format(position), callback, with_token=True)
+            token = self.command(u"MA {}\r".format(position), callback, with_token=True)
+            self.get_moving_state()
+            return token
         except ValueError as e:
             self.logger.exception(e)
             raise DeviceError(e)
