@@ -416,9 +416,9 @@ class DevicePi(DeviceSocket):
             if command == "ERR?\n" and error_code != 0:
                 readout_buffer = self.error_description.get(error_code, "Unknown error")
                 self.handle_command_error(command, readout_buffer)
-                command = RESPONSE_ERROR.decode()
+                command = RESPONSE_ERROR
             elif command not in ("#5\n", "#9\n", "STP\n") and error_code != 0:
-                command = RESPONSE_ERROR.decode()
+                command = RESPONSE_ERROR
                 readout_buffer = self.error_description.get(error_code, "Unknown error")
                 self.handle_command_error(command, readout_buffer)
 
