@@ -45,20 +45,29 @@ class DummyScanner(DeviceScanner):
                                                            maximum_velocity,
                                                            trigger_log=False,
                                                            negative_tolerance=mv.negative_tolerance(),
-                                                           positive_tolerance=mv.positive_tolerance())
+                                                           positive_tolerance=mv.positive_tolerance(),
+                                                           on_warning=scanner_input.step_attributes["on_warning"],
+                                                           timeout=scanner_input.step_attributes["timeout"]
+                                                           )
             position_step_0 = StepDeviceAttributeNumerical("SetInitPositionStep", device_id, ATTR_POSITION,
                                                            scanner_input.start_point,
                                                            trigger_log=False,
                                                            negative_tolerance=scanner_input.step_attributes[
                                                                "negative_tolerance"],
                                                            positive_tolerance=scanner_input.step_attributes[
-                                                               "positive_tolerance"])
+                                                               "positive_tolerance"],
+                                                           on_warning=scanner_input.step_attributes["on_warning"],
+                                                           timeout=scanner_input.step_attributes["timeout"]
+                                                           )
             macro.add(velocity_step_0)
             macro.add(position_step_0)
         velocity_step_1 = StepDeviceAttributeNumerical("FinalVelocityStep", device_id, ATTR_MAXIMUM_VELOCITY,
                                                        final_velocity,
                                                        trigger_log=False, negative_tolerance=mv.negative_tolerance(),
-                                                       positive_tolerance=mv.positive_tolerance())
+                                                       positive_tolerance=mv.positive_tolerance(),
+                                                       on_warning=scanner_input.step_attributes["on_warning"],
+                                                       timeout=scanner_input.step_attributes["timeout"]
+                                                       )
         macro.add(velocity_step_1)
         macro.add(scanner_input)
         # velocity_step_2 = StepDeviceAttributeNumerical("PreviousVelocityStep", device_id, ATTR_MAXIMUM_VELOCITY,
